@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -226,10 +226,20 @@ defaultFont()
 }
 
 
+QFont
+largeFont()
+{
+    QFont f;
+    f.setPointSize( defaultFontSize() + 4 );
+    return f;
+}
+
+
 void
 setDefaultFontSize( int points )
 {
     s_defaultFontSize = points;
+    s_defaultFontHeight = 0;  // Recalculate on next call to defaultFontHeight()
 }
 
 
