@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2019, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -163,16 +163,17 @@ LocalePage::LocalePage( QWidget* parent )
     {
         LCLocaleDialog* dlg =
                 new LCLocaleDialog( m_selectedLocaleConfiguration.isEmpty() ?
-                                        guessLocaleConfiguration().lang :
-                                        m_selectedLocaleConfiguration.lang,
+                                        guessLocaleConfiguration().language() :
+                                        m_selectedLocaleConfiguration.language(),
                                     m_localeGenLines,
                                     this );
         dlg->exec();
         if ( dlg->result() == QDialog::Accepted &&
              !dlg->selectedLCLocale().isEmpty() )
         {
-            m_selectedLocaleConfiguration.lang = dlg->selectedLCLocale();
+            m_selectedLocaleConfiguration.setLanguage( dlg->selectedLCLocale() );
             m_selectedLocaleConfiguration.explicit_lang = true;
+            this->updateGlobalLocale();
             this->updateLocaleLabels();
         }
 
@@ -316,7 +317,7 @@ LocalePage::init( const QString& initialRegion,
         }
         else
         {
-            cDebug() << "Cannot open file" << localeGenPath
+            cWarning() << "Cannot open file" << localeGenPath
                      << ". Assuming the supported languages are already built into "
                         "the locale archive.";
             QProcess localeA;
@@ -385,7 +386,7 @@ std::pair< QString, QString > LocalePage::prettyLocaleStatus( const LocaleConfig
 {
     return std::make_pair< QString, QString >(
         tr( "The system language will be set to %1." )
-            .arg( prettyLCLocale( lc.lang ) ),
+            .arg( prettyLCLocale( lc.language() ) ),
         tr( "The numbers and dates locale will be set to %1." )
                             .arg( prettyLCLocale( lc.lc_numeric ) )
                                              );
@@ -440,7 +441,8 @@ LocalePage::onActivate()
          !m_selectedLocaleConfiguration.explicit_lang )
     {
         auto newLocale = guessLocaleConfiguration();
-        m_selectedLocaleConfiguration.lang = newLocale.lang;
+        m_selectedLocaleConfiguration.setLanguage( newLocale.language() );
+        updateGlobalLocale();
         updateLocaleLabels();
     }
 }
@@ -449,20 +451,7 @@ LocalePage::onActivate()
 LocaleConfiguration
 LocalePage::guessLocaleConfiguration() const
 {
-    QLocale myLocale;   // User-selected language
-
-    // If we cannot say anything about available locales
-    if ( m_localeGenLines.isEmpty() )
-    {
-        cWarning() << "guessLocaleConfiguration can't guess from an empty list.";
-        return LocaleConfiguration::createDefault();
-    }
-
-    QString myLanguageLocale = myLocale.name();
-    if ( myLanguageLocale.isEmpty() )
-        return LocaleConfiguration::createDefault();
-
-    return LocaleConfiguration::fromLanguageAndLocation( myLanguageLocale,
+    return LocaleConfiguration::fromLanguageAndLocation( QLocale().name(),
                                                          m_localeGenLines,
                                                          m_tzWidget->getCurrentLocation().country );
 }
@@ -481,22 +470,34 @@ LocalePage::prettyLCLocale( const QString& lcLocale ) const
                           .arg( QLocale::countryToString( locale.country() ) );
 }
 
+
+void
+LocalePage::updateGlobalLocale()
+{
+    auto *gs = Calamares::JobQueue::instance()->globalStorage();
+    const QString bcp47 = m_selectedLocaleConfiguration.toBcp47();
+    gs->insert( "locale", bcp47 );
+}
+
+
 void
 LocalePage::updateGlobalStorage()
 {
-    LocaleGlobal::Location location = m_tzWidget->getCurrentLocation();
-    Calamares::JobQueue::instance()->globalStorage()
-            ->insert( "locationRegion", location.region );
-    Calamares::JobQueue::instance()->globalStorage()
-            ->insert( "locationZone", location.zone );
+    auto *gs = Calamares::JobQueue::instance()->globalStorage();
 
-    const QString bcp47 = m_selectedLocaleConfiguration.toBcp47();
-    Calamares::JobQueue::instance()->globalStorage()->insert( "locale", bcp47 );
+    LocaleGlobal::Location location = m_tzWidget->getCurrentLocation();
+    bool locationChanged = ( location.region != gs->value( "locationRegion" ) ) ||
+                           ( location.zone != gs->value( "locationZone" ) );
+
+    gs->insert( "locationRegion", location.region );
+    gs->insert( "locationZone", location.zone );
+
+    updateGlobalLocale();
 
     // If we're in chroot mode (normal install mode), then we immediately set the
     // timezone on the live system. When debugging timezones, don't bother.
 #ifndef DEBUG_TIMEZONES
-    if ( Calamares::Settings::instance()->doChroot() )
+    if ( locationChanged && Calamares::Settings::instance()->doChroot() )
     {
         QProcess::execute( "timedatectl",  // depends on systemd
                             { "set-timezone",
@@ -508,7 +509,7 @@ LocalePage::updateGlobalStorage()
     auto newLocale = guessLocaleConfiguration();
     if ( !m_selectedLocaleConfiguration.isEmpty() &&
          m_selectedLocaleConfiguration.explicit_lang )
-        newLocale.lang = m_selectedLocaleConfiguration.lang;
+        newLocale.setLanguage( m_selectedLocaleConfiguration.language() );
     if ( !m_selectedLocaleConfiguration.isEmpty() &&
          m_selectedLocaleConfiguration.explicit_lc )
     {
